@@ -1,4 +1,3 @@
 from .cli.main import main
-import sys
 
-sys.exit(main())
+main()
